@@ -54,7 +54,7 @@ use Carp;
 use Fcntl qw(O_RDONLY);
 
 # pinned to the latest MEME Suite version (x.yy.z), and then versioned from there
-use version; our $VERSION = version->declare("v4.12.0.1.1");
+use version; our $VERSION = version->declare("v4.12.0.1.2");
 
 require Exporter;
 our @ISA = qw(Exporter);
@@ -912,7 +912,7 @@ sub translate_seq {
 sub get_Weblogo_colour_args {
     my $self = shift;
 
-    my $arg_string = '';
+    my $arg_string = "";
 
     foreach my $letter ($self->get_core()) {
         my $sym = $self->{lookup}->{$letter};
@@ -920,7 +920,7 @@ sub get_Weblogo_colour_args {
         # convert back from decoded hex, adding '#' prefix
         my $HTML_colour = sprintf("#%X", $sym->{colour});
 
-        $arg_string .= '--color '.$HTML_colour.' '.$sym->{sym}.' '.$sym->{name}.' ';
+        $arg_string .= "--color '$HTML_colour' '$sym->{sym}' '$sym->{name}' ";
     }
 
     return $arg_string;
